@@ -5,6 +5,8 @@
 #include "simdjson/portability.h"
 #include <cstring>
 
+#ifndef SIMDJSON_DISABLE_DEPRECATED_API
+
 namespace simdjson {
 
 // VS2017 reports deprecated warnings when you define a deprecated class's methods.
@@ -12,7 +14,6 @@ SIMDJSON_PUSH_DISABLE_WARNINGS
 SIMDJSON_DISABLE_DEPRECATED_WARNING
 
 // Because of template weirdness, the actual class definition is inline in the document class
-
 simdjson_warn_unused bool dom::parser::Iterator::is_ok() const {
   return location < tape_length;
 }
@@ -480,7 +481,9 @@ bool dom::parser::Iterator::relative_move_to(const char *pointer,
 }
 
 SIMDJSON_POP_DISABLE_WARNINGS
-
 } // namespace simdjson
 
+#endif // SIMDJSON_DISABLE_DEPRECATED_API
+
+
 #endif // SIMDJSON_INLINE_PARSEDJSON_ITERATOR_H
