@@ -5,98 +5,166 @@ using namespace std;
 using namespace simdjson;
 using error_code=simdjson::error_code;
 
+bool string1() {
+  const char * data = "my data"; // 7 bytes
+  simdjson::padded_string my_padded_data(data, 7); // copies to a padded buffer
+  std::cout << my_padded_data << std::endl;
+  return true;
+}
+
+bool string2() {
+  std::string data = "my data";
+  simdjson::padded_string my_padded_data(data); // copies to a padded buffer
+  std::cout << my_padded_data << std::endl;
+  return true;
+}
 
 
 #if SIMDJSON_EXCEPTIONS
+bool gen_raw1() {
+  TEST_START();
+  simdjson::ondemand::parser parser;
+  simdjson::padded_string docdata =  R"({"value":123})"_padded;
+  simdjson::ondemand::document doc = parser.iterate(docdata);
+  simdjson::ondemand::object obj = doc.get_object();
+  string_view token = obj.raw_json(); // gives you `{"value":123}`
+  ASSERT_EQUAL(token, R"({"value":123})");
+  TEST_SUCCEED();
+}
 
-  bool number_tests() {
-    ondemand::parser parser;
-    padded_string docdata = R"([1.0, 3, 1, 3.1415,-13231232,9999999999999999999])"_padded;
-    ondemand::document doc = parser.iterate(docdata);
-    ondemand::array arr = doc.get_array();
-    for(ondemand::value val : arr) {
-      std::cout << val << " ";
-      std::cout << "negative: " << val.is_negative() << " ";
-      std::cout << "is_integer: " << val.is_integer() << " ";
-      ondemand::number num = val.get_number();
-      ondemand::number_type t = num.get_number_type();
-      // direct computation without materializing the number:
-      ondemand::number_type dt = val.get_number_type();
-      if(t != dt) { throw std::runtime_error("bug"); }
-      switch(t) {
-        case ondemand::number_type::signed_integer:
-          std::cout  << "integer: " << int64_t(num) << " ";
-          std::cout  << "integer: " << num.get_int64() << std::endl;
-          break;
-        case ondemand::number_type::unsigned_integer:
-          std::cout  << "large 64-bit integer: " << uint64_t(num) << " ";
-          std::cout << "large 64-bit integer: " << num.get_uint64() << std::endl;
-          break;
-        case ondemand::number_type::floating_point_number:
-          std::cout  << "float: " << double(num) << " ";
-          std::cout << "float: " << num.get_double() << std::endl;
-          break;
-      }
-    }
-    return true;
+bool gen_raw2() {
+  TEST_START();
+  simdjson::ondemand::parser parser;
+  simdjson::padded_string docdata =  R"([1,2,3])"_padded;
+  simdjson::ondemand::document doc = parser.iterate(docdata);
+  simdjson::ondemand::array arr = doc.get_array();
+  string_view token = arr.raw_json(); // gives you `[1,2,3]`
+  ASSERT_EQUAL(token, R"([1,2,3])");
+  TEST_SUCCEED();
+}
+
+bool gen_raw3() {
+  TEST_START();
+  simdjson::ondemand::parser parser;
+  simdjson::padded_string docdata =  R"({"value":123})"_padded;
+  simdjson::ondemand::document doc = parser.iterate(docdata);
+  simdjson::ondemand::object obj = doc.get_object();
+  string_view token = obj.raw_json(); // gives you `{"value":123}`
+  ASSERT_EQUAL(token, R"({"value":123})");
+  obj.reset(); // revise the object
+  uint64_t x = obj["value"]; // gives me 123
+  ASSERT_EQUAL(x, 123);
+
+  TEST_SUCCEED();
+}
+
+bool at_end() {
+  TEST_START();
+  auto json = R"([1, 2] foo ])"_padded;
+  ondemand::parser parser;
+  ondemand::document doc = parser.iterate(json);
+  ondemand::array array = doc.get_array();
+  for (uint64_t values : array) {
+    std::cout << values << std::endl;
   }
+  if(!doc.at_end()) {
+    std::cerr << "trailing content at byte index " << doc.current_location() - json.data() << std::endl;
+  }
+  TEST_SUCCEED();
+}
 
-void recursive_print_json(ondemand::value element) {
-    bool add_comma;
-    switch (element.type()) {
-    case ondemand::json_type::array:
-      cout << "[";
-      add_comma = false;
-      for (auto child : element.get_array()) {
-        if (add_comma) {
-          cout << ",";
-        }
-        // We need the call to value() to get
-        // an ondemand::value type.
-        recursive_print_json(child.value());
-        add_comma = true;
-      }
-      cout << "]";
-      break;
-    case ondemand::json_type::object:
-      cout << "{";
-      add_comma = false;
-      for (auto field : element.get_object()) {
-        if (add_comma) {
-          cout << ",";
-        }
-        // key() returns the key as it appears in the raw
-        // JSON document, if we want the unescaped key,
-        // we should do field.unescaped_key().
-        cout << "\"" << field.key() << "\": ";
-        recursive_print_json(field.value());
-        add_comma = true;
-      }
-      cout << "}\n";
-      break;
-    case ondemand::json_type::number:
-      // assume it fits in a double
-      cout << element.get_double();
-      break;
-    case ondemand::json_type::string:
-      // get_string() would return escaped string, but
-      // we are happy with unescaped string.
-      cout << "\"" << element.get_raw_json_string() << "\"";
-      break;
-    case ondemand::json_type::boolean:
-      cout << element.get_bool();
-      break;
-    case ondemand::json_type::null:
-      // we check that the value is indeed null
-      // otherwise: an error is thrown.
-      if(element.is_null()) {
-        cout << "null";
-      }
-      break;
+bool number_tests() {
+  TEST_START();
+  ondemand::parser parser;
+  padded_string docdata = R"([1.0, 3, 1, 3.1415,-13231232,9999999999999999999])"_padded;
+  ondemand::document doc = parser.iterate(docdata);
+  ondemand::array arr = doc.get_array();
+  for(ondemand::value val : arr) {
+    std::cout << val << " ";
+    std::cout << "negative: " << val.is_negative() << " ";
+    std::cout << "is_integer: " << val.is_integer() << " ";
+    ondemand::number num = val.get_number();
+    ondemand::number_type t = num.get_number_type();
+    // direct computation without materializing the number:
+    ondemand::number_type dt = val.get_number_type();
+    if(t != dt) { throw std::runtime_error("bug"); }
+    switch(t) {
+      case ondemand::number_type::signed_integer:
+        std::cout  << "integer: " << int64_t(num) << " ";
+        std::cout  << "integer: " << num.get_int64() << std::endl;
+        break;
+      case ondemand::number_type::unsigned_integer:
+        std::cout  << "large 64-bit integer: " << uint64_t(num) << " ";
+        std::cout << "large 64-bit integer: " << num.get_uint64() << std::endl;
+        break;
+      case ondemand::number_type::floating_point_number:
+        std::cout  << "float: " << double(num) << " ";
+        std::cout << "float: " << num.get_double() << std::endl;
+        break;
     }
+  }
+  TEST_SUCCEED();
+}
+
+bool recursive_print_json(ondemand::value element) {
+  TEST_START();
+  bool add_comma;
+  switch (element.type()) {
+  case ondemand::json_type::array:
+    cout << "[";
+    add_comma = false;
+    for (auto child : element.get_array()) {
+      if (add_comma) {
+        cout << ",";
+      }
+      // We need the call to value() to get
+      // an ondemand::value type.
+      recursive_print_json(child.value());
+      add_comma = true;
+    }
+    cout << "]";
+    break;
+  case ondemand::json_type::object:
+    cout << "{";
+    add_comma = false;
+    for (auto field : element.get_object()) {
+      if (add_comma) {
+        cout << ",";
+      }
+      // key() returns the key as it appears in the raw
+      // JSON document, if we want the unescaped key,
+      // we should do field.unescaped_key().
+      cout << "\"" << field.key() << "\": ";
+      recursive_print_json(field.value());
+      add_comma = true;
+    }
+    cout << "}\n";
+    break;
+  case ondemand::json_type::number:
+    // assume it fits in a double
+    cout << element.get_double();
+    break;
+  case ondemand::json_type::string:
+    // get_string() would return escaped string, but
+    // we are happy with unescaped string.
+    cout << "\"" << element.get_raw_json_string() << "\"";
+    break;
+  case ondemand::json_type::boolean:
+    cout << element.get_bool();
+    break;
+  case ondemand::json_type::null:
+    // we check that the value is indeed null
+    // otherwise: an error is thrown.
+    if(element.is_null()) {
+      cout << "null";
+    }
+    break;
+  }
+  TEST_SUCCEED();
 }
 
 bool basics_treewalk() {
+  TEST_START();
   padded_string json[3] = {R"( [
     { "make": "Toyota", "model": "Camry",  "year": 2018, "tire_pressure": [ 40.1, 39.9, 37.7, 40.4 ] },
     { "make": "Kia",    "model": "Soul",   "year": 2012, "tire_pressure": [ 30.1, 31.0, 28.6, 28.7 ] },
@@ -109,77 +177,82 @@ bool basics_treewalk() {
     recursive_print_json(val);
     std::cout << std::endl;
   }
-  return true;
+  TEST_SUCCEED();
 }
 
-void print_depth_space(ondemand::value element) {
+bool print_depth_space(ondemand::value element) {
+  TEST_START();
   for(auto i = 0; i < element.current_depth(); i++) {
     cout << " ";
   }
+  TEST_SUCCEED();
 }
 
-void recursive_print_json_breakline(ondemand::value element) {
-    bool add_comma;
-    switch (element.type()) {
-    case ondemand::json_type::array:
-      cout << endl;
-      print_depth_space(element);
-      cout << "[";
-      add_comma = false;
-      for (auto child : element.get_array()) {
-        if (add_comma) {
-          print_depth_space(element);
-          cout << ",";
-        }
-        // We need the call to value() to get
-        // an ondemand::value type.
-        recursive_print_json_breakline(child.value());
-        add_comma = true;
+bool recursive_print_json_breakline(ondemand::value element) {
+  TEST_START();
+  bool add_comma;
+  switch (element.type()) {
+  case ondemand::json_type::array:
+    cout << endl;
+    print_depth_space(element);
+    cout << "[";
+    add_comma = false;
+    for (auto child : element.get_array()) {
+      if (add_comma) {
+        print_depth_space(element);
+        cout << ",";
       }
-      cout << "]";
-      break;
-    case ondemand::json_type::object:
-      cout << endl;
-      print_depth_space(element);
-      cout << "{";
-      add_comma = false;
-      for (auto field : element.get_object()) {
-        if (add_comma) {
-          print_depth_space(element);
-          cout << ",";
-        }
-        // key() returns the key as it appears in the raw
-        // JSON document, if we want the unescaped key,
-        // we should do field.unescaped_key().
-        cout << "\"" << field.key() << "\": ";
-        recursive_print_json_breakline(field.value());
-        add_comma = true;
-      }
-      cout << "}\n";
-      break;
-    case ondemand::json_type::number:
-      // assume it fits in a double
-      cout << element.get_double();
-      break;
-    case ondemand::json_type::string:
-      // get_string() would return escaped string, but
-      // we are happy with unescaped string.
-      cout << "\"" << element.get_raw_json_string() << "\"";
-      break;
-    case ondemand::json_type::boolean:
-      cout << element.get_bool();
-      break;
-    case ondemand::json_type::null:
-      // We check that the value is indeed null
-      // otherwise: an error is thrown.
-      if(element.is_null()) {
-        cout << "null";
-      }
-      break;
+      // We need the call to value() to get
+      // an ondemand::value type.
+      recursive_print_json_breakline(child.value());
+      add_comma = true;
     }
+    cout << "]";
+    break;
+  case ondemand::json_type::object:
+    cout << endl;
+    print_depth_space(element);
+    cout << "{";
+    add_comma = false;
+    for (auto field : element.get_object()) {
+      if (add_comma) {
+        print_depth_space(element);
+        cout << ",";
+      }
+      // key() returns the key as it appears in the raw
+      // JSON document, if we want the unescaped key,
+      // we should do field.unescaped_key().
+      cout << "\"" << field.key() << "\": ";
+      recursive_print_json_breakline(field.value());
+      add_comma = true;
+    }
+    cout << "}\n";
+    break;
+  case ondemand::json_type::number:
+    // assume it fits in a double
+    cout << element.get_double();
+    break;
+  case ondemand::json_type::string:
+    // get_string() would return escaped string, but
+    // we are happy with unescaped string.
+    cout << "\"" << element.get_raw_json_string() << "\"";
+    break;
+  case ondemand::json_type::boolean:
+    cout << element.get_bool();
+    break;
+  case ondemand::json_type::null:
+    // We check that the value is indeed null
+    // otherwise: an error is thrown.
+    if(element.is_null()) {
+      cout << "null";
+    }
+    break;
+  }
+  TEST_SUCCEED();
 }
 
 bool basics_treewalk_breakline() {
+  TEST_START();
   padded_string json[3] = {R"( [
     { "make": "Toyota", "model": "Camry",  "year": 2018, "tire_pressure": [ 40.1, 39.9, 37.7, 40.4 ] },
     { "make": "Kia",    "model": "Soul",   "year": 2012, "tire_pressure": [ 30.1, 31.0, 28.6, 28.7 ] },
@@ -192,7 +265,7 @@ bool basics_treewalk_breakline() {
     recursive_print_json_breakline(val);
     std::cout << std::endl;
   }
-  return true;
+  TEST_SUCCEED();
 }
 
 bool basics_1() {
@@ -416,6 +489,40 @@ bool using_the_parsed_json_3() {
   TEST_SUCCEED();
 }
 
+bool using_the_parsed_json_3b() {
+  TEST_START();
+  ondemand::parser parser;
+  auto cars_json = R"( {
+    "identifier1":{ "make": "Toyota", "model": "Camry",  "year": 2018, "tire_pressure": [ 40.1, 39.9, 37.7, 40.4 ] },
+    "identifier2":{ "make": "Kia",    "model": "Soul",   "year": 2012, "tire_pressure": [ 30.1, 31.0, 28.6, 28.7 ] },
+    "identifier3":{ "make": "Toyota", "model": "Tercel", "year": 1999, "tire_pressure": [ 29.8, 30.0, 30.2, 30.5 ] }
+  } )"_padded;
+
+  // Iterating through an array of objects
+  ondemand::document doc = parser.iterate(cars_json);
+  for (ondemand::field key_car : doc.get_object()) {
+    // If I need a string_view and/or, I can use key_car.unescaped_key() instead, but
+    // key_car.key() will be more performant otherwise.
+    cout << "identifier : " << key_car.key() << std::endl;
+    // I can now access the subobject:
+    ondemand::object car = key_car.value();
+    // Accessing a field by name
+    cout << "Make/Model: " << std::string_view(car["make"]) << "/" << std::string_view(car["model"]) << endl;
+
+    // Casting a JSON element to an integer
+    uint64_t year = car["year"];
+    cout << "- This car is " << 2020 - year << "years old." << endl;
+
+    // Iterating through an array of floats
+    double total_tire_pressure = 0;
+    for (double tire_pressure : car["tire_pressure"]) {
+      total_tire_pressure += tire_pressure;
+    }
+    cout << "- Average tire pressure: " << (total_tire_pressure / 4) << endl;
+  }
+
+  TEST_SUCCEED();
+}
 
 bool using_the_parsed_json_rewind() {
   TEST_START();
@@ -542,7 +649,7 @@ bool using_the_parsed_json_no_exceptions() {
     cout << "Make/Model: " << make << "/" << model << endl;
 
     // Casting a JSON element to an integer
-    uint64_t year;
+    uint64_t year{};
     error = car["year"].get(year);
     if(error) { std::cerr << error << std::endl; return false; }
     cout << "- This car is " << 2020 - year << " years old." << endl;
@@ -661,7 +768,7 @@ bool json_pointer_multiple() {
 	ASSERT_SUCCESS(cars.count_elements().get(size));
 	double expected[] = {39.9, 31, 30};
 	for (size_t i = 0; i < size; i++) {
-		std::string json_pointer = "/" + std::to_string(i) + "/tire_pressure/1";
+		std::string json_pointer = std::string("/") + std::to_string(i) + std::string("/tire_pressure/1");
 		double x;
 		ASSERT_SUCCESS(cars.at_pointer(json_pointer).get(x));
 		ASSERT_EQUAL(x,expected[i]);
@@ -744,9 +851,9 @@ bool ndjson_basics_example() {
   size_t count{0};
   int64_t expected[3] = {1,2,3};
   for (auto doc : docs) {
-    int64_t actual;
+    int64_t actual{};
     ASSERT_SUCCESS( doc["foo"].get(actual) );
-    ASSERT_EQUAL( actual,expected[count++] );
+    ASSERT_EQUAL( actual, expected[count++] );
   }
   TEST_SUCCEED();
 }
@@ -914,6 +1021,38 @@ int load_example_except() {
   std::cout << identifier << std::endl;
   return EXIT_SUCCESS;
 }
+int load_example_except_morecomplete(void) {
+  TEST_START();
+  simdjson::ondemand::parser parser;
+  simdjson::padded_string json_string;
+  simdjson::ondemand::document doc;
+  try {
+    json_string = padded_string::load("twitter.json");
+    doc = parser.iterate(json_string);
+    uint64_t identifier = doc["statuses"].at(0)["id"];
+    std::cout << identifier << std::endl;
+  } catch (simdjson::simdjson_error &error) {
+    std::cerr << "JSON error: " << error.what() << " near "
+              << doc.current_location() << " in " << json_string << std::endl;
+  }
+  return EXIT_SUCCESS;
+}
+
+bool allow_comma_separated_example() {
+  TEST_START();
+  auto json = R"( 1, 2, 3, 4, "a", "b", "c", {"hello": "world"} , [1, 2, 3])"_padded;
+  ondemand::parser parser;
+  ondemand::document_stream doc_stream;
+  // We pass '32' as the batch size, but it is a bogus parameter because, since
+  // we pass 'true' to the allow_comma parameter, the batch size will be set to at least
+  // the document size.
+  auto error = parser.iterate_many(json, 32, true).get(doc_stream);
+  if(error) { std::cerr << error << std::endl; return false; }
+  for (auto doc : doc_stream) {
+    std::cout << doc.type() << std::endl;
+  }
+  TEST_SUCCEED();
+}
 #endif
 bool test_load_example() {
   TEST_START();
@@ -939,7 +1078,8 @@ bool current_location_tape_error() {
   int64_t i;
   ASSERT_ERROR(doc["integer"].get_int64().get(i), TAPE_ERROR);
   ASSERT_SUCCESS(doc.current_location().get(ptr));
-  ASSERT_EQUAL(ptr, "false, \"integer\": -343} ");
+  std::string expected = "false, \"integer\": -343} ";
+  ASSERT_EQUAL(std::string(ptr,expected.size()), expected);
   TEST_SUCCEED();
 }
 
@@ -953,7 +1093,8 @@ bool current_location_user_error() {
   int64_t i;
   ASSERT_ERROR(doc["integer"].get_int64().get(i), INCORRECT_TYPE);
   ASSERT_SUCCESS(doc.current_location().get(ptr));
-  ASSERT_EQUAL(ptr, "[1,2,3] ");
+  std::string expected = "[1,2,3] ";
+  ASSERT_EQUAL(std::string(ptr, expected.size()), expected);
   TEST_SUCCEED();
 }
 
@@ -987,15 +1128,195 @@ bool current_location_no_error() {
     auto error = val.get_object().get(obj);
     if (!error) {
       ASSERT_SUCCESS(doc.current_location().get(ptr));
-      ASSERT_EQUAL(ptr, "\"key\": \"value\"}, true] ");
+      std::string expected = "\"key\": \"value\"}, true] ";
+      ASSERT_EQUAL(std::string(ptr, expected.size()), expected);
     }
   }
   TEST_SUCCEED();
 }
 
+
+
+struct ZuluBBox {
+  double xmin;
+  double ymin;
+  double width;
+  double height;
+
+  void print() {
+    std::cout << xmin << ", " << ymin << ", " << width << ", " << height
+              << std::endl;
+  }
+};
+#if SIMDJSON_EXCEPTIONS
+
+bool example1956() {
+
+  auto json = R"+( {
+  "ZuluROI": {
+    "ZuluBBox": {
+      "xmin": 0,
+      "ymin": 0,
+      "width": 1,
+      "height": 1
+    },
+    "SubObjects": [
+      {
+        "ZuluDetection": {
+          "label": "car",
+          "class_id": 3,
+          "confidence": 0.7587034106254578,
+          "ZuluBBox": {
+            "xmin": 0.3843536376953125,
+            "ymin": 0.4532909393310547,
+            "width": 0.09115534275770187,
+            "height": 0.04127710685133934
+          },
+          "SubObjects": []
+        }
+      },
+      {
+        "ZuluDetection": {
+          "label": "car",
+          "class_id": 3,
+          "confidence": 0.6718865633010864,
+          "ZuluBBox": {
+            "xmin": 0.7500002980232239,
+            "ymin": 0.5212296843528748,
+            "width": 0.07592231780290604,
+            "height": 0.038947589695453644
+          },
+          "SubObjects": []
+        }
+      },
+      {
+        "ZuluDetection": {
+          "label": "car",
+          "class_id": 3,
+          "confidence": 0.5806200504302979,
+          "ZuluBBox": {
+            "xmin": 0.9025363922119141,
+            "ymin": 0.5925348401069641,
+            "width": 0.05478987470269203,
+            "height": 0.046337299048900604
+          },
+          "SubObjects": []
+        }
+      }
+    ]
+  },
+  "timestamp (ms)": 1677085594421,
+  "buffer_offset": 35673
+} )+"_padded;
+  ondemand::parser parser;
+  ondemand::document doc = parser.iterate(json);
+  ondemand::object root_object = doc.get_object();
+  ondemand::object roi_object = root_object["ZuluROI"];
+
+  ondemand::object box_roi_object = roi_object["ZuluBBox"];
+  ZuluBBox box = {
+      double(box_roi_object["xmin"]), double(box_roi_object["ymin"]),
+      double(box_roi_object["width"]), double(box_roi_object["height"])};
+  box.print();
+
+  for (ondemand::object value : roi_object["SubObjects"]) {
+    ondemand::object detect = value["ZuluDetection"];
+    std::cout << detect["label"].get_string() << std::endl;
+    std::cout << detect["class_id"].get_uint64() << std::endl;
+    std::cout << detect["confidence"].get_double() << std::endl;
+
+    ondemand::object vbox_roi_object = detect["ZuluBBox"];
+    ZuluBBox vbox = {
+        double(vbox_roi_object["xmin"]), double(vbox_roi_object["ymin"]),
+        double(vbox_roi_object["width"]), double(vbox_roi_object["height"])};
+    vbox.print();
+  }
+
+  std::cout << root_object["timestamp (ms)"].get_uint64() << std::endl;
+  std::cout << root_object["buffer_offset"].get_uint64() << std::endl;
+  return true;
+}
+
+
+bool example1958() {
+  auto json = R"+( {
+    "5f08a730b280e54fd1e75a7046b93fdc": {
+        "file": "/DEMOS/0-9/10_Orbyte.sid",
+        "len": [
+            "1:17"
+        ],
+        "loud": [
+            "-22.8"
+        ],
+        "name": "10 Orbyte",
+        "author": "Michael Becker (Premium)",
+        "release": "2014 Tristar & Red Sector Inc.",
+        "bits": 20
+    },
+    "2727236ead44a62f0c6e01f6dd4dc484": {
+        "file": "/DEMOS/0-9/12345.sid",
+        "len": [
+            "0:56"
+        ],
+        "loud": [
+            "-33.3"
+        ],
+        "name": "12345",
+        "author": "Beal",
+        "release": "1988 Beal",
+        "bits": 20
+    },
+    "7ea765fce6c0f92570b18adc7bf52f54": {
+        "file": "/DEMOS/0-9/128_Byte_Blues_BASIC.sid",
+        "len": [
+            "0:18"
+        ],
+        "loud": [
+            "-27.1"
+        ],
+        "name": "128 Byte Blues",
+        "author": "Leonard J. Paul (Freaky DNA)",
+        "release": "2005 Freaky DNA",
+        "bits": 62
+    }
+} )+"_padded;
+  ondemand::parser parser;
+  ondemand::document doc = parser.iterate(json);
+  ondemand::object root_object = doc.get_object();
+  for(auto key_value : root_object) {
+    // could get std::string_view with 'unescaped_key()':
+    std::cout << "key: " << key_value.key() << std::endl;
+    ondemand::object obj = key_value.value();
+
+    std::cout << "file: " << std::string_view(obj["file"]) << std::endl;
+
+    std::cout << "len: ";
+    for(std::string_view values : obj["len"]) {
+      std::cout << values << std::endl;
+    }
+    std::cout << std::endl;
+
+    std::cout << "loud: ";
+    for(std::string_view values : obj["loud"]) {
+      std::cout << values << std::endl;
+    }
+    std::cout << std::endl;
+
+    std::cout << "name: " << std::string_view(obj["name"]) << std::endl;
+    std::cout << "author: " << std::string_view(obj["author"]) << std::endl;
+    std::cout << "release: " << std::string_view(obj["release"]) << std::endl;
+    std::cout << "bits: " << uint64_t(obj["bits"]) << std::endl;
+  }
+  return true;
+}
+#endif
 bool run() {
   return true
 #if SIMDJSON_EXCEPTIONS
+    && gen_raw1() && gen_raw2() && gen_raw3()
+    && at_end()
+    && example1956() && example1958()
+    && allow_comma_separated_example()
 //    && basics_1() // Fails because twitter.json isn't in current directory. Compile test only.
     &&  basics_treewalk()
     &&  basics_treewalk_breakline()
@@ -1012,6 +1333,7 @@ bool run() {
     && big_integer()
     && big_integer_in_string()
     && using_the_parsed_json_3()
+    && using_the_parsed_json_3b()
     && using_the_parsed_json_4()
     && using_the_parsed_json_5()
 #endif
